@@ -240,7 +240,7 @@ class StreamApp(object):
             module = str(config.PARAM_PATH)
             param_module = importlib.import_module(module)
             param_class = getattr(param_module, param_type)
-            param = param_class(name=param_name, value=param_value)
+            param = param_class(name=param_name)
             setattr(args, param_variable, param_value)
             setattr(args, param_variable+"_object", param)
         return args
